# Mypy Type Check Coverage Summary

Summary from index
File | Imprecision | Lines
--- | --- | ---
Total | 19.50% imprecise | 1564 LOC
hatch_ci | 0.00% imprecise | 2 LOC
hatch_ci._support | 45.38% imprecise | 119 LOC
hatch_ci.cli | 19.57% imprecise | 138 LOC
hatch_ci.code | 29.37% imprecise | 126 LOC
hatch_ci.common | 0.00% imprecise | 3 LOC
hatch_ci.exceptions | 45.71% imprecise | 35 LOC
hatch_ci.fileos | 3.27% imprecise | 153 LOC
hatch_ci.hook_build | 45.59% imprecise | 68 LOC
hatch_ci.hook_metadata | 0.00% imprecise | 0 LOC
hatch_ci.hook_version | 21.62% imprecise | 37 LOC
hatch_ci.hooks | 14.29% imprecise | 14 LOC
hatch_ci.scm | 11.19% imprecise | 286 LOC
hatch_ci.script | 27.59% imprecise | 174 LOC
hatch_ci.text | 0.00% imprecise | 24 LOC
hatch_ci.tools | 11.69% imprecise | 385 LOC